@@ -150,6 +150,10 @@ class METSALTOHandler(FileHandler):
                 raise MetsTagNotFound("Could not find mets tag!")
             return soup
 
+        except MetsTagNotFound as e:
+            logger.error(f"Error reading METS file: {e}")
+            raise e
+
         except Exception as e:
             logger.error(f"Error reading METS file: {e}")
 
